@@ -1,6 +1,8 @@
 import asyncio
 import pyppeteer
 import random
+from pyppeteer_stealth import stealth
+
 class browser:
     def __init__(self, url):
         self.url = url
@@ -16,10 +18,10 @@ class browser:
         ]
 
         self.options = {
-        'args': self.args,
-        'headless': True,
-        'ignoreHTTPSErrors': True,
-        'userDataDir': "./tmp"
+            'args': self.args,
+            'headless': True,
+            'ignoreHTTPSErrors': True,
+            'userDataDir': "./tmp"
         }
 
         asyncio.get_event_loop().run_until_complete(self.start())
@@ -28,41 +30,27 @@ class browser:
         self.browser = await pyppeteer.launch(self.options)
         self.page = await self.browser.newPage()
 
+        await stealth(self.page)
+
         await self.page.emulate({'viewport': {
-            'width':random.randint(320, 1920),
-            'height':random.randint(320, 1920),
-            'deviceScaleFactor':random.randint(1, 3),
-            'isMobile':random.random() > 0.5,
+            'width': random.randint(320, 1920),
+            'height': random.randint(320, 1920),
+            'deviceScaleFactor': random.randint(1, 3),
+            'isMobile': random.random() > 0.5,
             'hasTouch': random.random() > 0.5
         }})
 
         await self.page.setUserAgent(self.userAgent)
 
         await self.page.goto("https://www.tiktok.com/trending?lang=en", {
-        'waitUntil': "load"
+            'waitUntil': "load"
         })
 
-        await self.page.evaluate('''() => {
-          var b = {};
-          for (let x of window.webpackJsonp) {
-            if (typeof x[1]["duD4"] === "function") {
-              x[1]["duD4"](null, b);
-              break;
-            }
-          }
-
-          if (typeof b.sign !== "function") {
-            throw "No function found";
-          }
-
-          window.generateSignature = function generateSignature(url) {
-              return b.sign({ url: url });
-          };
+        self.signature = await self.page.evaluate('''() => {
+          var t = {}
+          webpackJsonp.filter(x => typeof x[1]['duD4'] === "function")[0][1].duD4(null, t)
+          var url = "''' + self.url + '''"
+          var token = t.sign({url: url})
+          return token;
           }''')
-        
-        self.signature = await self.sign(self.url)
         await self.browser.close()
-
-    async def sign(self, string):
-        res = await self.page.evaluate("generateSignature('" + string + "')")
-        return res
